{
  description = "Builder of the nicomem.com website";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-25.05";

    flake-utils.url = "github:numtide/flake-utils";
  };

  outputs =
    { nixpkgs, flake-utils, ... }:
    flake-utils.lib.eachDefaultSystem (
      system:
      let
        pkgs = nixpkgs.legacyPackages.${system};
      in
      {
        packages = rec {
          backend = pkgs.callPackage ./packages/backend { };
          frontend = pkgs.callPackage ./packages/frontend { };
          all = pkgs.symlinkJoin {
            name = "all";
            paths = [
              backend
              frontend
            ];
          };
          default = all;
        };

        devShells.default = pkgs.mkShell {
          packages = [
            pkgs.bashInteractive

            # Frontend
            pkgs.nodejs
            pkgs.yarn

            # Backend
            pkgs.cargo
            pkgs.rustfmt
            pkgs.clippy
            pkgs.rustc
          ];

          shellHook = ''
            # Needed for rust-analyzer
            export RUST_SRC_PATH="${pkgs.rust.packages.stable.rustPlatform.rustLibSrc}";
          '';
        };
      }
    );
}
